Page 19 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 19

Home

    Hide me from the secret counsel of the wicked; from the
    insurrection of the workers of iniquity: . . .
    Psalm 64:2

    Since early times, "Wise Men" have existed who
    claimed knowledge of "Mysteries" that were to be kept
    secret from all outside their circle. Some of these

    mysteries purported to relate to such matters as the origin
    of man, life of the soul after death, and the nature of

    God. These mysteries were usually handed down by oral
    tradition and kept from the ordinary people.

    Many Jewish writers believe that Moses drew from
    the Egyptian Mysteries a part of an oral tradition handed
    down through the leaders of the Israelites (the Jews), and
    later written in the Talmud and the Cabala. Others

    believe that an oral tradition goes back to Adam. There
    was a conflict here, and it could be found not only in
    traditions, but in the resulting polarization of the Jews
    with one side supporting orthodox Judaism and one side
    working to undermine it.

    That there existed a secret oral tradition claiming to
    be the teaching of Moses, but contrary to the Law, could

    explain why ‘many Jewish people “were so quick to
    forsake the written Law of Moses and join in worshiping

    14

    Chapter 3

    Ancient Oral Traditions

    "Wise Men" have existed who